@@ -10,6 +10,7 @@ import re
 import time
 from multiprocessing import Process, Manager, Lock
 import setproctitle
+import shlex
 
 from cli_helpers.tabular_output import TabularOutputFormatter
 from cli_helpers.tabular_output import preprocessors
@@ -1076,8 +1077,16 @@ class SQLCli(object):
             raise SQLCliException("Please load driver first.")
 
         # 去掉为空的元素
-        # connect_parameters = [var for var in re.split(r'//|:|@| |/', arg) if var]
-        connect_parameters = re.split(r'://|:|@|/', arg)
+        # connect_parameters = re.split(r'://|:|@|/|\s+', arg)
+
+        m_connect_parameterlist = shlex.shlex(arg)
+        m_connect_parameterlist.whitespace = '://|:|@| '
+        m_connect_parameterlist.quotes = '"'
+        m_connect_parameterlist.whitespace_split = True
+        connect_parameters = list(m_connect_parameterlist)
+        for m_nPos in range(0, len(connect_parameters)):
+            if connect_parameters[m_nPos].startswith('"') and connect_parameters[m_nPos].endswith('"'):
+                connect_parameters[m_nPos] = connect_parameters[m_nPos][1:-1]
         if len(connect_parameters) == 8:
             # 指定了所有的数据库连接参数
             self.db_username = connect_parameters[0]
@@ -1120,8 +1129,7 @@ class SQLCli(object):
                                               "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
                 else:
                     # 用户第一次连接，而且没有指定环境变量
-                    raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
-                                          "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
+                    raise SQLCliException("Missed SQLCLI_CONNECTION_URL in env.")
         elif len(connect_parameters) == 4:
             # 用户写法是connect user xxx password xxxx; 密码可能包含引号
             if connect_parameters[0].upper() == "USER" and connect_parameters[2].upper() == "PASSWORD":
@@ -1152,10 +1160,11 @@ class SQLCli(object):
                                                   "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
                     else:
                         # 用户第一次连接，而且没有指定环境变量
-                        raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
-                                              "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
+                        raise SQLCliException("Missed SQLCLI_CONNECTION_URL in env.")
         else:
             # 不知道的参数写法
+            if "SQLCLI_DEBUG" in os.environ:
+                print("DEBUG:: Connect Str =[" + str(connect_parameters) + "]")
             raise SQLCliException("Missing required argument\n." + "connect [user name]/[password]@" +
                                   "jdbc:[db type]:[driver type]://[host]:[port]/[service name]")
 
@@ -1222,6 +1231,8 @@ class SQLCli(object):
             if "SQLCLI_DEBUG" in os.environ:
                 print('traceback.print_exc():\n%s' % traceback.print_exc())
                 print('traceback.format_exc():\n%s' % traceback.format_exc())
+                print("db_user = [" + str(self.db_username) + "]")
+                print("db_pass = [" + str(self.db_password) + "]")
                 print("db_type = [" + str(self.db_type) + "]")
                 print("db_host = [" + str(self.db_host) + "]")
                 print("db_port = [" + str(self.db_port) + "]")
@@ -1263,12 +1274,20 @@ class SQLCli(object):
             m_Result = []
             for m_Session_Name, m_Connection in self.db_saved_conn.items():
                 m_Result.append([str(m_Session_Name), str(m_Connection[1]), str(m_Connection[2])])
-            yield (
-                "Saved Sessions",
-                m_Result,
-                ["Sesssion Name", "User Name", "URL"],
-                ""
-            )
+            if len(m_Result) == 0:
+                yield (
+                    None,
+                    None,
+                    None,
+                    "No saved sesssions."
+                )
+            else:
+                yield (
+                    "Saved Sessions",
+                    m_Result,
+                    ["Sesssion Name", "User Name", "URL"],
+                    "Total " + str(len(m_Result)) + " saved sesssions."
+                )
             return
 
         # 要求两个参数 save/restore [session_name]
@@ -1295,7 +1314,11 @@ class SQLCli(object):
         else:
             raise SQLCliException(
                 "Wrong argument : " + "Session save/restore [session name]")
-        return [(None, None, None, "Session Operate Successful.")]
+        if m_Parameters[0] == 'save':
+            yield None, None, None, "Session saved Successful."
+        if m_Parameters[0] == 'restore':
+            yield None, None, None, "Session restored Successful."
+        return
 
     # 休息一段时间, 如果收到SHUTDOWN或者ABORT符号的时候，立刻终止SLEEP
     def sleep(self, arg, **_):
@@ -1375,7 +1398,7 @@ class SQLCli(object):
     def execute_internal_command(self, arg, **_):
         # 创建数据文件, 根据末尾的rows来决定创建的行数
         # 此时，SQL语句中的回车换行符没有意义
-        matchObj = re.match(r"create\s+file\s+(.*?)\((.*)\)(\s+)?rows\s+([1-9]\d*)(\s+)?(;)?$",
+        matchObj = re.match(r"create\s+file\s+(.*?)\((.*)\)(\s+)?rows\s+(\d+)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             # create file command  将根据格式要求创建需要的文件
@@ -1391,7 +1414,7 @@ class SQLCli(object):
             return
 
         #  创建数据文件
-        matchObj = re.match(r"create\s+file\s+(.*?)\((.*)\)(\s+)?(;)?$",
+        matchObj = re.match(r"create\s+file\s+(.*?)\((.*)\)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             # create file command  将根据格式要求创建需要的文件
@@ -1407,7 +1430,7 @@ class SQLCli(object):
             return
 
         #  在不同的文件中进行相互转换
-        matchObj = re.match(r"create\s+file\s+(.*?)\s+from\s+(.*?)(\s+)?(;)?$",
+        matchObj = re.match(r"create\s+file\s+(.*?)\s+from\s+(.*?)(\s+)?$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
             # 在不同的文件中相互转换
@@ -1422,19 +1445,34 @@ class SQLCli(object):
             return
 
         # 创建随机数Seed的缓存文件
-        matchObj = re.match(r"create\s+seeddatafile(\s+)?;$",
+        matchObj = re.match(r"create\s+seeddatafile\s+(.*)\s+with\s+null\s+rows\s+(\d+)$",
                             arg, re.IGNORECASE | re.DOTALL)
         if matchObj:
-            Create_SeedCacheFile()
+            m_strSeedFile = str(matchObj.group(1)).lstrip().rstrip()
+            m_nNullValueCount = int(matchObj.group(2))
+            Create_SeedCacheFile(p_szSeedName=m_strSeedFile, p_nNullValueCount=m_nNullValueCount)
             yield (
                 None,
                 None,
                 None,
-                'file created Successful.')
+                'seed file created Successful.')
+            return
+
+        # 创建随机数Seed的缓存文件
+        matchObj = re.match(r"create\s+seeddatafile\s+(.*)(\s+)?$",
+                            arg, re.IGNORECASE | re.DOTALL)
+        if matchObj:
+            m_strSeedFile = str(matchObj.group(1))
+            Create_SeedCacheFile(p_szSeedName=m_strSeedFile)
+            yield (
+                None,
+                None,
+                None,
+                'seed file created Successful.')
             return
 
         # 不认识的internal命令
-        raise SQLCliException("Unknown internal Command. Please double check.")
+        raise SQLCliException("Unknown internal Command [" + str(arg) + "]. Please double check.")
 
     # 逐条处理SQL语句
     # 如果执行成功，返回true
@@ -1694,16 +1732,6 @@ class SQLCli(object):
             output = itertools.chain(output, [title])
 
         if cur:
-            # 列的数据类型，如果不存在，按照None来处理
-            column_types = None
-            if hasattr(cur, "description"):
-                def get_col_type(col):
-                    # col_type = FIELD_TYPES.get(col[1], text_type)
-                    # return col_type if type(col_type) is type else text_type
-                    return str
-
-                column_types = [get_col_type(col) for col in cur.description]
-
             if max_width is not None:
                 cur = list(cur)
 
@@ -1711,7 +1739,7 @@ class SQLCli(object):
                 cur,
                 headers,
                 format_name=p_format_name,
-                column_types=column_types,
+                column_types=None,
                 **output_kwargs
             )
             if isinstance(formatted, str):
